@@ -5,14 +5,16 @@ import stun
 
 
 def main():
-    parser = optparse.OptionParser()
+    parser = optparse.OptionParser(version=stun.__version__)
     parser.add_option("-d", "--debug", dest="DEBUG", action="store_true",
                       default=False, help="Enable debug logging")
-    parser.add_option("-H", "--host", dest="stun_host", default=None, help="STUN host to use")
+    parser.add_option("-H", "--host", dest="stun_host", default=None,
+                      help="STUN host to use")
     parser.add_option("-i", "--interface", dest="source_ip", default="0.0.0.0",
                       help="network interface for client (default: 0.0.0.0)")
-    parser.add_option("-p", "--port", dest="source_port", type="int", default=54320,
-                      help="port to listen on for client (default: 54320)")
+    parser.add_option("-p", "--port", dest="source_port", type="int",
+                      default=54320, help="port to listen on for client "
+                      "(default: 54320)")
     (options, args) = parser.parse_args()
     if options.DEBUG:
         stun.enable_logging()
